@@ -943,93 +943,3 @@ def ProfilePack2Visual(ProfilePack, combomode = np.mean,
     cV = combomode(ProfilePack, axis = 0) 
     xlabels = np.linspace(0, Vsize, xlabelsnum, dtype = int)
     vismode(cV, bounds = bounds, xlabels = xlabels, labels = labels, suptitle = suptitle, figsize = figsize, fontsize = fontsize, cmap = cmap)
-    
-<<<<<<< HEAD
-    return 
-=======
-    return 
-
-
-
-
-
-
-
-
-
-
-
-''' def KmerFinder(SeqCurrent, kmer, center = None, extend = None): 
-    
-    lkmer = len(kmer)
-    
-    ms = []
-    for z in SeqCurrent: 
-        lz = len(z)
-        m = np.repeat(0, lz-lkmer + 1)
-        for ir, r in enumerate(z[:-lkmer]): 
-            j = z[ir:ir+lkmer]
-            if j == kmer or reverse_complement(j) == kmer: 
-                m[z][ir] = 1
-        if center is not None: m = np.concatenate([np.repeat(center, window // 2), m])
-        if extend is not None: m = np.concatenate([t, np.repeat(extend, lz - len(m))])
-        ms.append(m.reshape(-1,1)) 
-
-    return ms ''' 
-
-'''def Seq2PWMScore(seq, PWM, pieces = None, center = None, extend = None): 
-    # introduce pieces for long seq 
-    
-    ls, lp = len(seq), len(PWM)
-    
-    pieces = 1 if pieces == None else pieces
-    parts = np.linspace(0, ls - lp + 1, pieces + 1, dtype = int)
-    
-    scores = []
-    for i in range(pieces): 
-        sp = seq[parts[i]:parts[i+1] + lp - 1]
-        s = Seqs2OHE(sp)
-        r = np.lib.stride_tricks.sliding_window_view(s, (lp, 4))
-        s1 = np.tensordot(r, PWM, axes=((2,3),(0,1))).reshape(-1)
-        del s,r
-        s_rc = Seqs2OHE(reverse_complement(sp))
-        r_rc = np.lib.stride_tricks.sliding_window_view(s_rc, (lp, 4))
-        s2 = np.tensordot(r_rc, PWM, axes=((2,3),(0,1))).reshape(-1)
-        del s_rc,r_rc
-
-        scores.append(np.max([s1, s2[::-1]], axis = 0))
-    
-    scores = np.concatenate(scores)
-    if center is not None: scores = np.concatenate([np.repeat(center, lp // 2), scores])
-    if center is not None: scores = np.concatenate([scores, np.repeat(extend, ls - len(scores))])
-        
-    return scores.reshape(-1,1)'''
-
-
-
-''' def SigCurrent2Markers(SigCurrent, BS_ids, select_BS_ids = None, reso = 1, top = None, smallest = False): 
-    #makes a sigCurrent out of non zero values. Recommended to make a BinCurrent from CurrentThresholder first or filter out values you dont want
-    
-    if top is not None: 
-        allvals = np.concatenate(SigCurrent, axis = 0).reshape(-1)
-        k = 1 if smallest == True else -1
-        thresh = allvals[np.argsort(allvals)[::k]][top]
-        pdx = [np.where(z > thresh)[0] for z in SigCurrent] if smallest == False else [np.where(z < thresh)[0] for z in SigCurrent]
-   
-    else: pdx = [np.where(z != 0) for z in SigCurrent]
-
-    Markers = []
-    for ip, p in enumerate(pdx): 
-        lp = len(p)
-        vals = (SigCurrent[ip][p]).reshape(-1)
-        subseqs, strand, size = [np.repeat(x, lp) for x in [select_BS_ids[ip], 0, 1]]
-        Markers.append(np.stack([subseqs, p, strand, size, vals], axis = 1))
-    Markers = np.vstack(Markers)
-    d = pd.DataFrame(Markers, columns = ['subseq', 'loc', 'strand', 'size', 'val'])
-    d[['loc', 'strand', 'size']] = d[['loc', 'strand', 'size']].astype(int)
-    d[['val']] = d[['val']].astype(float)
-    
-    d = d.sort_values(by=['subseq', 'loc', 'strand'])
-    
-    return d '''
->>>>>>> 19a30b5ca75d9a7ab060f717dea33005fee9078d
